@@ -39,7 +39,8 @@ tw_get_cached_search <- function(search,
 
   table_name <- tw_get_cache_table_name(
     type = stringr::str_c("search_", type),
-    language = language_combo
+    language = language,
+    response_language = response_language
   )
 
   if (pool::dbExistsTable(conn = db, name = table_name) == FALSE) {
